<?php
/**
 * Plugin Name: Palestine Corner
 * Description: Adds a small icon in the corner of every page with configurable click behavior.
 * Version:     1.0.0
 * Author:      Your Name
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Palestine_Corner_Plugin {
    public function __construct() {
        add_action( 'admin_menu', [ $this, 'add_admin_menu' ] );
        add_action( 'admin_init', [ $this, 'settings_init' ] );
        add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_assets' ] );
        add_action( 'wp_footer', [ $this, 'render_icon' ] );
    }

    public function add_admin_menu() {
        add_options_page(
            'Palestine Corner',
            'Palestine Corner',
            'manage_options',
            'palestine_corner',
            [ $this, 'options_page' ]
        );
    }

    public function settings_init() {
        register_setting( 'palestine_corner_settings', 'palestine_corner_options' );

        add_settings_section(
            'palestine_corner_section',
            'Icon Behavior Settings',
            null,
            'palestine_corner'
        );

        add_settings_field(
            'palestine_corner_action',
            'On Click Action',
            [ $this, 'action_field_render' ],
            'palestine_corner',
            'palestine_corner_section'
        );

        add_settings_field(
            'palestine_corner_link',
            'Link URL (if applicable)',
            [ $this, 'link_field_render' ],
            'palestine_corner',
            'palestine_corner_section'
        );
    }

    public function action_field_render() {
        $opts = get_option( 'palestine_corner_options', [] );
        printf(
            '<select name="palestine_corner_options[action]">'
          . '<option value="hide" %s>Hide Icon</option>'
          . '<option value="link" %s>Open Link</option>'
          . '</select>',
            selected( $opts['action'] ?? '', 'hide', false ),
            selected( $opts['action'] ?? '', 'link', false )
        );
    }

    public function link_field_render() {
        $opts = get_option( 'palestine_corner_options', [] );
        printf(
            '<input type="url" name="palestine_corner_options[link]" value="%s" placeholder="https://example.com" style="width:100%%;" />',
            esc_attr( $opts['link'] ?? '' )
        );
    }

    public function options_page() {
        echo '<form action="options.php" method="post">';
        settings_fields( 'palestine_corner_settings' );
        do_settings_sections( 'palestine_corner' );
        submit_button();
        echo '</form>';
    }

    public function enqueue_assets() {
        wp_enqueue_style( 'palestine-corner-css', plugin_dir_url( __FILE__ ) . 'css/palestine-corner.css' );
        wp_enqueue_script( 'palestine-corner-js', plugin_dir_url( __FILE__ ) . 'js/palestine-corner.js', [ 'jquery' ], false, true );
        wp_localize_script( 'palestine-corner-js', 'PalestineCornerOptions', get_option( 'palestine_corner_options', [] ) );
    }

    public function render_icon() {
        if ( ! is_front_page() ) {
            return;
        }
        echo '<div id="palestine-corner-icon">'
           . '<img src="' . esc_url( plugin_dir_url( __FILE__ ) . 'images/icon.png' ) . '" alt="Icon"/>'
           . '</div>';
    }
}

new Palestine_Corner_Plugin();
